==> haskell-time-manager-0.0.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-88mBEP6srToBSn5NA7u0cm
key:                  time-manager-0.0.1-88mBEP6srToBSn5NA7u0cm
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  3d625290a25861e70d65fdd85587d6cd
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-88mBEP6srToBSn5NA7u0cm
depends:
    auto-update-0.1.6-JieGKtau1agIwYwJbPzwoO base-4.17.2.1
    unliftio-0.2.25.1-4Wsc1Zb3eoWC4jfumimD4V

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-time-manager-0.0.1-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-time-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-manager
version:              0.0.1
visibility:           public
id:                   time-manager-0.0.1-DkYipttg1Wb4qBJR7PusWr
key:                  time-manager-0.0.1-DkYipttg1Wb4qBJR7PusWr
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Michael Snoyman and Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Scalable timer
description:          Scalable timer functions provided by a timer manager.
category:             System
abi:                  5a3e57b6b457e6b430b9ac4e618441f2
exposed:              True
exposed-modules:      System.TimeManager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/time-manager-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.4.8/time-manager-0.0.1
hs-libraries:         HStime-manager-0.0.1-DkYipttg1Wb4qBJR7PusWr
depends:
    auto-update-0.1.6-EOLb1ANaASJByEN3pUlUBf base-4.17.2.1
    unliftio-0.2.25.1-Az2ajR7TJn65JyIPm5hx9P

haddock-interfaces:
    /usr/share/doc/haskell-time-manager/html/time-manager.haddock

haddock-html:         /usr/share/doc/haskell-time-manager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
